Issue 78
A. Gallo et alii, Fracture and Structural Integrity, 78 (2026) 489-503; DOI: 10.3221/IGF-ESIS.78.28
The inclusion of the Lagrange multiplier increases the number of unknowns but guarantees exact constraint satisfaction at convergence, while maintaining physical dimensional consistency. The optimized configuration resulted in a significant reduction of plate mass, i.e. 21.21%, with a von Mises peak stress variation of about 0.16%. Although the Lagrange multiplier theoretically enforces the equality constraint at convergence, i.e. Δσ = 0, a small residual deviation can be mainly attributable to mesh discretization, solver convergence tolerances, and the numerical approximation of the von Mises peak stress. The resulting deviation below 0.2% can be considered numerically negligible in the analysed finite element problem, while the physical consistency of the optimized solution is maintained. The final design variables, together with the corresponding mass and stress values, are summarized in Tab. 3:
Optimized with LM
Optimized with NLS
Optimized with MBS
Reference
206000
- - -
- - -
- - -
E [MPa]
ν [-] [ ] ௪ [ ] [ ] [ ] [ ] [ ] ℎ തതതത
0.3
16.985 16.985
16.835
16.734
17.013 182.74 783.39 392.95
80.00
82.06
94.10
800.00 400.00
812.38 388.24
791.05 393.83
7.78
7.04
6.99
6.13
Table 3 : Calibrated parameters of structural optimization. In this case, the minimum of the objective function was reached in 81 minutes and 34 iterations. Optimized geometry is shown in Fig. 7.
Figure 7 : Optimized geometry Since no benchmark was available, comparisons with a standard Newton scheme ( ൌ 1 ) without Wolfe conditions, LM approach and Newton method with line search were performed. Convergence with standard Newton method was reached after 50 iterations carried out in 142 minutes, resulting a mass reduction of the 9.89% but with a 1.65% decrease of von Mises stress. The results with LM algorithm, reported in Tab. 3, show a 9.51% decrease in mass with a 0.88% reduction of von Mises stress, obtained after 15 iterations and approximately 6 hours of computational time. A 10.15% mass reduction was achieved using NLS in 43 minutes and 36 iterations, although a 1.5% deviation from the stress constraint was also observed. Despite its lower computational cost in comparison with MBS, the NLS method failed to satisfy the prescribed constraint. Therefore, MBS framework provided both greater mass reduction and more precise constraint enforcement. For this test case, a sensitivity analysis was also conducted using the same initial guesses to assess the influence of the parameter ψ on computational efficiency and solution quality. Three values of ψ were considered, namely 0.9, 0.8, and 0.7. For all ψ , the algorithm converged to mass values that, rounded to two decimal places, were the same as MBS outcome reported in
502
Made with FlippingBook Online newsletter creator